@@ -53,6 +53,7 @@ except ImportError:
 
 
 __all__ = (
+    'AuthAnonymous',
     'AuthScram',
     'AuthCryptoSign',
     'AuthWampCra',
@@ -151,13 +152,13 @@ class AuthCryptoSign(object):
                 raise ValueError(
                     "Unexpected key '{}' for {}".format(key, self.__class__.__name__)
                 )
-        for key in ['privkey', 'authid']:
+        for key in ['privkey']:
             if key not in kw:
                 raise ValueError(
                     "Must provide '{}' for cryptosign".format(key)
                 )
         for key in kw.get('authextra', dict()):
-            if key not in ['pubkey']:
+            if key not in ['pubkey', 'channel_binding']:
                 raise ValueError(
                     "Unexpected key '{}' in 'authextra'".format(key)
                 )
@@ -578,7 +579,7 @@ def generate_wcs(length=14):
     :rtype: bytes
     """
     assert(type(length) == int)
-    return "".join([random.choice(WCS_SECRET_CHARSET) for _ in range(length)]).encode('ascii')
+    return "".join(random.choice(WCS_SECRET_CHARSET) for _ in range(length)).encode('ascii')
 
 
 @public
